@@ -25,7 +25,7 @@ BEGIN
   our %EXPORT_TAGS = ( go => [@EXPORT_OK] );
 }
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 require App::MechaCPAN::Perl;
 require App::MechaCPAN::Install;
@@ -50,6 +50,7 @@ my @args = (
   'verbose|v!',
   'quiet|q!',
   'no-log!',
+  'directory|d=s',
 );
 @args = keys %{ { map { $_ => 1 } @args } };
 
@@ -64,12 +65,6 @@ sub main
 {
   my @argv = @_;
 
-  my $options = {};
-  my $getopt_ret
-    = Getopt::Long::GetOptionsFromArray( \@argv, $options, @args );
-  return -1
-    if !$getopt_ret;
-
   if ( $0 =~ m/zhuli/ )
   {
     if ( $argv[0] =~ m/^do the thing/i )
@@ -88,8 +83,38 @@ sub main
     }
   }
 
-  local $LOGFH;
+  my $options = {};
+  my $getopt_ret
+    = Getopt::Long::GetOptionsFromArray( \@argv, $options, @args );
+  return -1
+    if !$getopt_ret;
+
+  my $merge_options = sub
+  {
+    my $arg = shift;
+    if ( ref $arg eq 'HASH' )
+    {
+      $options = { %$arg, %$options };
+
+      #say Data::Dumper::Dumper($arg, $options);
+      return 0;
+    }
+    return 1;
+  };
+
+  @argv = grep { $merge_options->($_) } @argv;
+
   my $orig_dir = cwd;
+  if ( exists $options->{directory} )
+  {
+    if ( !-d $options->{directory} )
+    {
+      die "Cannot find directory: $options->{directory}\n";
+    }
+    chdir $options->{directory};
+  }
+
+  local $LOGFH;
   my $dest_dir = &dest_dir;
   my $cmd      = ucfirst lc shift @argv;
   my $pkg      = join( '::', __PACKAGE__, $cmd );
@@ -101,14 +126,10 @@ sub main
     return -1;
   }
 
-  if ( ref $argv[0] eq 'HASH' )
-  {
-    $options = shift @argv;
-  }
-
   if ( $options->{'diag-run'} )
   {
     warn "Would run '$cmd'\n";
+    chdir $orig_dir;
     return 0;
   }
 
@@ -678,6 +699,10 @@ Using quiet means that the normal information descriptions are hidden. Note that
 
 A log is normally outputted into the C<local/logs> directory. This option will prevent a log from being created.
 
+=head2 --directory=<path>
+
+Changes to a specified directory before any processing is done. This allows you to specify what directory you want C<local/> to be in.
+
 =head2 C<$ENV{MECHACPAN_TIMEOUT}>
 
 Every command that C<App::MechaCPAN> runs is given an idle timeout before it is killed and a failure is returned. This timeout is reset every time the command outputs to C<STDOUT> or C<STDERR>. Using the environment variable C<MECHACPAN_TIMEOUT>, you can override or disable this timeout. It is always in seconds and setting it to 0 will disable it.
